@@ -1,6 +1,6 @@
 --[[
- POSIX library for Lua 5.1, 5.2 & 5.3.
- Copyright (C) 2014-2019 Gary V. Vaughan
+ POSIX library for Lua 5.1, 5.2, 5.3 & 5.4.
+ Copyright (C) 2014-2020 Gary V. Vaughan
 ]]
 --[[--
  Private argument checking helpers.
