@@ -1,6 +1,6 @@
 --[[
- POSIX library for Lua 5.1, 5.2 & 5.3.
- Copyright (C) 2014-2019 Gary V. Vaughan
+ POSIX library for Lua 5.1, 5.2, 5.3 & 5.4.
+ Copyright (C) 2014-2020 Gary V. Vaughan
 ]]
 --[[--
  Legacy Lua POSIX bindings.
@@ -34,9 +34,9 @@ local S_IXUSR = require 'posix.sys.stat'.S_IXUSR
 local argerror = require 'posix._base'.argerror
 local argscheck = require 'posix._base'.argscheck
 local chmod = require 'posix.sys.stat'.chmod
-local band = require 'bit32'.band
-local bnot = require 'bit32'.bnot
-local bor = require 'bit32'.bor
+local band = require 'posix._base'.band
+local bnot = require 'posix._base'.bnot
+local bor = require 'posix._base'.bor
 local concat = table.concat
 local gsub = string.gsub
 local match = string.match
