@@ -1,6 +1,6 @@
 --[[
- POSIX library for Lua 5.1, 5.2 & 5.3.
- Copyright (C) 2014-2019 Gary V. Vaughan
+ POSIX library for Lua 5.1, 5.2, 5.3 & 5.4.
+ Copyright (C) 2014-2020 Gary V. Vaughan
 ]]
 --[[--
  Legacy Lua POSIX bindings.
@@ -12,6 +12,8 @@
 
 local HAVE_DEBUG, _debug = pcall(require, 'std._debug')
 
+local argerror = require 'posix._base'.argerror
+
 local _ENV = require 'posix._strict' {
    CLOCK_MONOTONIC = require 'posix.time'.CLOCK_MONOTONIC,
    CLOCK_PROCESS_CPUTIME_ID = require 'posix.time'.CLOCK_PROCESS_CPUTIME_ID,
@@ -56,10 +58,9 @@ local _ENV = require 'posix._strict' {
    _SC_TZNAME_MAX = require 'posix.unistd'._SC_TZNAME_MAX,
    _SC_VERSION = require 'posix.unistd'._SC_VERSION,
    _debug = HAVE_DEBUG and _debug or {},
-   argerror = require 'posix._base'.argerror,
    argscheck = require 'posix._base'.argscheck,
    bind = require 'posix.sys.socket'.bind,
-   bor = require 'bit32'.bor,
+   bor = require 'posix._base'.bor,
    clock_getres = require 'posix.time'.clock_getres or false,
    clock_gettime = require 'posix.time'.clock_gettime or false,
    connect = require 'posix.sys.socket'.connect,
